// ETELSAT.H
//
// Copyright (c) 1997-2000 Symbian Ltd.  All rights reserved.
//

/** @file Etelsat.h
 * ETel SAT header file.
 *
 * Describes the SAT API - classes, nethods and types.
 */


#if !defined(__ETELSAT_H__)
#define __ETELSAT_H__

#include <e32base.h>
#include <s32mem.h>
#include <ETEL.h>

const TInt KETelExtSatV1=5000;	// For passing into RTelServer::IsSupportedByModule()

// SAT extended errors
// SAT allocacted error space ranges from -5250 to -5299
const TInt KErrSatBase=-5250;
const TInt KErrSatBusy=KErrSatBase-1;
const TInt KErrSatControl=KErrSatBase-2;

// Forward declaration
class CSatPtrHolder;

/**
 * @class RSat Etelsat.h "inc/Etelsat.h"
 * @brief Handles the SAT interface between client and TSY.
 *
 * RSat inherits from RTelSubSessionBase defined in ETEL.H
 * and is opened from RPhone.
 */

class RSat: public RTelSubSessionBase
	{
public:
	IMPORT_C RSat();
	IMPORT_C TInt Open(RPhone& aPhone);
	IMPORT_C void Close();

	IMPORT_C void NotifyProactiveSimSessionStart(TRequestStatus& aReqStatus) const;
	IMPORT_C void NotifyProactiveSimSessionStartCancel() const;
	
	IMPORT_C void NotifyProactiveSimSessionEnd(TRequestStatus& aReqStatus) const;
	IMPORT_C void NotifyProactiveSimSessionEndCancel() const;

	/** 
	* @class TSatBase etelsat.h "inc/etelsat.h"
	* @brief Base class for all the SAT ETel API parameters which are version dependent.
	*
	* TSatBase ExtensionId method is used to determine which version of a packaged
	* parameter has been created.
	*/
	class TSatBase
		{
	public:
		IMPORT_C TInt ExtensionId() const;
	protected:
		TSatBase();
	protected:
		TInt iExtensionId; ///< Extension identifier
		};

	/** 
	* @class TSatPCmdBase etelsat.h "inc/etelsat.h"
	* @brief Base class for all the SAT ETel API proactive command classes.
	*
	* TSatPCmdBase inherits from TSatBase and is the base class for all the SAT
	* ETel API proactive command classes, for which it holds the associated
	* proactive command number.
	*/
	class TSatPCmdBase : public TSatBase
		{
	public:
		IMPORT_C TUint8 PCmdNumber() const;
		IMPORT_C TInt SetPCmdNumber(TUint8 aNumber);
	protected:
		TSatPCmdBase();
	protected:
		TUint8 iPCmdNumber; ///< Valid range is 0x01 to 0xFE, dictated by ETSI 11.14
		};

	enum TSatVersion
		{
		KSatVersionNotSet=-1,	///< Sat version has not been set yet
		KSatV1=1				///< Sat version 1
		};	
	
	enum THelp
		{
		EHelpNotSet,
		EHelpAvailable,
		ENoHelpAvailable
		};

	enum TTimeUnit
		{
		ETimeUnitNotSet,
		ENoDurationAvailable,
		EMinutes,
		ESeconds,
		ETenthsOfSeconds
		};

	struct TDuration
		{
		TTimeUnit iTimeUnit;	///< Unit used to encode the duration in iNumOfUnits
		TUint8 iNumOfUnits;		///< Valid range is 1 to 255.
		};
	
	// Alpha Identifier
	enum {KAlphaIdMaxSize=254};
	typedef TBuf<KAlphaIdMaxSize> TAlphaIdBuf;

	enum TAlphaIdStatus
		{
		EAlphaIdProvided,
		EAlphaIdNull,
		EAlphaIdNotPresent
		};

	struct TAlphaId
		{
		TAlphaIdStatus iStatus; ///< Status of the alpha identifier (provided and not null, null or not present)
		TAlphaIdBuf iAlphaId;	///< Alpha Identifier
		};

	// TCcp ( Capability configuration parameters) is a 8-bit data buffer 
	// that contains the bearer capabilities as coded in ETSI 11.11 and ETSI 04.08.
	// It is 14 bytes as it does not include the IEI (Information Element Identity).
	enum {KCcpMaxSize=14};
	typedef TBuf8<KCcpMaxSize> TCcp; 

	enum {KSubAddressMaxSize=21};
	typedef TBuf<KSubAddressMaxSize> TSubAddress;

	enum TTypeOfNumber
		{
		ETypeOfNumberNotSet,
		EUnknownNumber,
		EInternationalNumber,
		ENationalNumber,
		ENetworkSpecificNumber,
		EDedicatedNumber
		};

	enum TNumberingPlan
		{
		ENumberingPlanNotSet,
		EUnknownNumberingPlan,
		EIsdnNumberPlan,
		EDataNumberPlan,
		ETelexNumberPlan,
		ENationalNumberPlan,
		EPrivateNumberPlan
		};
	
	enum {KMaxMobileTelNumberSize=251}; 
	typedef TBuf<KMaxMobileTelNumberSize> TSatTelNumber;

	struct TAddress
		{
		TTypeOfNumber iTypeOfNumber;
		TNumberingPlan iNumberPlan;
		TSatTelNumber iTelNumber; 
		};

	// Maximum size of a SS or a USSD string
	enum {KStringMaxSize=242};

	struct TSsString
		{
		TTypeOfNumber iTypeOfNumber;
		TNumberingPlan iNumberPlan;
		TBuf8<KStringMaxSize> iSsString;
		};

	struct TUssdString
		{
		TUint8 iDcs; ///< Data Coding Scheme
		TBuf<KStringMaxSize> iUssdString; 
		};

	enum TIconQualifier
		{
		EIconQualifierNotSet,	///< Icon qualifier is not set
		ENoIconId,				///< Icon qualifier not present			
		ESelfExplanatory,		///< Icon qualifier is self explanatory	(to display instead of the alpha id or text string)
		ENotSelfExplanatory		///< Icon qualifier is not self explanatory (to display along the alpha id or text string)
		};

	struct TIconId
		{
		TIconQualifier iQualifier;	///< Icon qualifier
		TUint8 iIdentifier;			///< Icon identifier, addresses a record in EF IMG
		};

	//
	// Read Icon
	//
	enum {KImageInstanceDescriptorsMaxSize=255};

	typedef TBuf8<KImageInstanceDescriptorsMaxSize> TIcon;
	
	IMPORT_C void GetIcon(TRequestStatus& aReqStatus, TUint8 aRecordNumber, TIcon& aIconEf) const;
	IMPORT_C void GetIconCancel() const;

	IMPORT_C void GetImageInstance(TRequestStatus& aReqStatus, TUint aInstanceNumber, TDes8& aInstance) const;
	IMPORT_C void GetImageInstanceCancel() const;

	// API/TSY internal type
	struct TInstanceNumberAndOffset
		{
		TUint iInstanceNumber;	///< Image instance number
		TUint iOffset;			///< Image instance offset within the image record
		};

	IMPORT_C void GetClut(TRequestStatus& aReqStatus, TUint aInstanceNumber, TUint aOffset, TDes8& aClut) const;
	IMPORT_C void GetClutCancel() const;

	//
	// Terminal Response - Answer from the client to a proactive command
	//

	// TPCmdResult enum values are dictated by ETSI 11.14
	enum TPCmdResult
		{
		KPCmdResultNotSet						=-1,
		KSuccess								=0x00,
		KPartialComprehension					=0x01,
		KMissingInformation						=0x02,
		KRefreshAdditionEFRead					=0x03,
		KSuccessRequestedIconNotDisplayed		=0x04,
		KModifiedByCallControl					=0x05,
		KPSessionTerminatedByUser				=0x10,
		KBackwardModeRequestedByUser			=0x11,
		KNoResponseFromUser						=0x12,
		KHelpRequestedByUser					=0x13,
		KUssdTransactionTerminatedByUser		=0x14,
		KMeUnableToProcessCmd					=0x20,
		KNetworkUnableToProcessCmd				=0x21,
		KCallSetUpNotAcceptedByUser				=0x22,
		KCallClearedBeforeConnectionOrReleased	=0x23,
		KContradictionWithTimerState			=0x24,
		KInteractionWithCCTemporaryError		=0x25,
		KCmdBeyondMeCapabilities				=0x30,
		KCmdTypeNotUnderstood					=0x31,
		KCmdDataNotUnderstood					=0x32,
		KCmdNumberNotKnown						=0x33,
		KSsReturnError							=0x34,
		KSmsRpError								=0x35,
		KErrorRequiredValuesMissing				=0x36,
		KUssdReturnError						=0x37,
		KInteractionWithCCPermanentError		=0x39
		};

	enum TAdditionalInfoType
		{
		KNoAdditionalInfo			= 0x0001,
		KMeProblem					= 0x0002,		
		KSatNetworkErrorInfo		= 0x0004,		
		KSendSsInfo					= 0x0008, 
		KTextString					= 0x0010, 
		KItemIdentifier				= 0x0020 
		};

	// TMeProblem enum values are dictated by ETSI 11.14
	enum TMeProblem
		{
		KNoSpecificCause			= 0x00,
		KScreenBusy					= 0x01,
		KMeBusyOnCall				= 0x02,
		KMeBusyOnSs					= 0x03,
		KNoService					= 0x04,
		KAccBar						= 0x05,
		KRadioRessourceNotGranted	= 0x06,
		KNotInSpeechCall			= 0x07,
		KMeBusyOnUssd				= 0x08,
		KMeBusyOnSendDtmf			= 0x09
		};

	enum {KAdditionalInfoMaxSize=244};

	typedef TBuf<KAdditionalInfoMaxSize> TAdditionalInfo;

	enum TPCmd
		{
		EDisplayText,
		EGetInkey,
		EGetInput,
		EPlayTone,
		ERefresh,
		ESelectItem,
		ESendDtmf,
		ESendSm,
		ESendSs,
		ESendUssd,
		ESetUpCall,
		ESetUpEventList,
		ESetUpIdleModeText,
		ESetUpMenu
		};

	IMPORT_C void TerminalRsp(TRequestStatus& aReqStatus, TPCmd aPCmd, const TDesC8& aRsp) const;
	IMPORT_C void TerminalRspCancel() const;

	//
	// TERMINAL PROFILE
	//

	// TSatProfileByteX enum values are dictated by ETSI 11.14

	enum TSatProfileByte1
		{
		KCapsProfileDownload		=0x01,
		KCapsSmsPpDataDownload		=0x02,
		KCapsCbDataDownload			=0x04,
		KCapsMenuSelection			=0x08,
		KCaps9EXX					=0x10,
		KCapsTimerExpiration		=0x20,
		KCapsUssdStringInCC			=0x40,
		KCapsRfu1					=0x80
		};

	enum TSatProfileByte2
		{
		KCapsCommandResult			=0x01,
		KCapsCCBySim				=0x02,
		KCapsCellIdInCCBySim		=0x04,
		KCapsMOSMControl			=0x08,
		KCapsAlphaIdHandling		=0x10,
		KCapsUcs2Entry				=0x20,
		KCapsUcs2Display			=0x40,
		KCapsExtensionTextDisplay	=0x80
		};

	enum TSatProfileByte3
		{
		KCapsDisplayText	=0x01,
		KCapsGetInkey		=0x02,
		KCapsGetInput		=0x04,
		KCapsMoreTime		=0x08,
		KCapsPlayTone		=0x10,
		KCapsPollInterval	=0x20,
		KCapsPollingOff		=0x40,
		KCapsRefresh		=0x80
		};

	enum TSatProfileByte4
		{
		KCapsSelectItem					=0x01,
		KCapsSendSM						=0x02,
		KCapsSendSS						=0x04,
		KCapsSendUSSD					=0x08,
		KCapsSetUpCall					=0x10,
		KCapsSetUpMenu					=0x20,
		KCapsProvideLocalInformation	=0x40,
		KCapsProvideLocalInformationNMR	=0x80
		};

	enum TSatProfileByte5
		{
		KCapsSetUpEventList				=0x01,
		KCapsMtCallEvent				=0x02,
		KCapsCallConnectedEvent			=0x04,
		KCapsCallDisconnectedEvent		=0x08,
		KCapsLocationStatusEvent		=0x10,
		KCapsUserActivityEvent			=0x20,
		KCapsIdleScreenAvailableEvent	=0x40,
		KCapsCardReaderStatusEvent		=0x80
		};

	enum TSatProfileByte6
		{
		//RFU
		};

	enum TSatProfileByte7
		{
		KCapsPowerOnCard		=0x01,
		KCapsPowerOffCard		=0x02,
		KCapsPerformCardApdu	=0x04,
		KCapsGetReaderStatus	=0x08
		//Other Values are RFU
		};

	enum TSatProfileByte8
		{
		KCapsTimerManagementStartStop			=0x01,
		KCapsTimerManagementGetCurrentValue		=0x02,
		KCapsProvideLocalInfoDateTimeTimeZone	=0x04,
		KCapsBinaryChoiceGetInkey				=0x08,
		KCapsSetUpIdleModeText					=0x10,
		KCapsRunAtCmd							=0x20,
		KCaps2ndAlphaIdSetUpCall				=0x40,
		KCaps2ndCapabilityConfigParam			=0x80
		};

	enum TSatProfileByte9
		{
		KCapsSustainedDisplayText		=0x01,
		KCapsSendDTMFCmd				=0x02,
		KCapsProvideLocalInfoBcchCoding	=0x04
		};

	/** 
	* @class TSatProfileV1 etelsat.h "inc/etelsat.h"
	* @brief States the SAT facilities supported by the Client and/or the ME-side
	*/
	class TSatProfileV1 : public TSatBase
		{
	public:
		IMPORT_C TSatProfileV1();

		TUint8 iSatProfileByte1;
		TUint8 iSatProfileByte2;
		TUint8 iSatProfileByte3;
		TUint8 iSatProfileByte4;
		TUint8 iSatProfileByte5;
		TUint8 iSatProfileByte6;
		TUint8 iSatProfileByte7;
		TUint8 iSatProfileByte8;
		TUint8 iSatProfileByte9;
		};

	typedef TPckg<TSatProfileV1>	TSatProfileV1Pckg;

	IMPORT_C void GetMeSideSatProfile(TRequestStatus& aReqStatus,TDes8& aMeSimSatProfile) const;
	IMPORT_C void GetMeSideSatProfileCancel() const;

	IMPORT_C TInt ClientSatProfileIndication(const TDesC8& aClientSatProfile) const;

	//
	// MENU SELECTION
	//
	enum THelpRequest
		{
		EHelpRequestNotSet,
		EHelpRequested,
		EHelpNotRequested
		};

	/** 
	* @class TMenuSelectionV1 etelsat.h "inc/etelsat.h"
	* @brief Describe the user SAT menu selection
	*/
	class TMenuSelectionV1 : public TSatBase
		{
	public:
		IMPORT_C TMenuSelectionV1();
	public:
		TUint8 iItemId;
		THelpRequest iHelp;
		};

	typedef TPckg<TMenuSelectionV1>	TMenuSelectionV1Pckg;

	IMPORT_C void MenuSelection(TRequestStatus& aReqStatus, const TDesC8& aSelection) const;
	IMPORT_C void MenuSelectionCancel() const;

	//
	// CALL CONTROL
	//
	enum TControlResult
		{
		EControlResultNotSet,
		EAllowedNoModification,
		ENotAllowed,
		EAllowedWithModifications
		};

	enum TCallControlType
		{
		ECcTypeNotSet,
		ECcAddress,
		ECcSsString,
		ECcUssdString
		};

	struct TCallSetUpParams
		{
		TCcp iCcp1;				///< Capability configuration parameters
		TSubAddress iSubAddress;///< Sub address
		TCcp iCcp2;				///< Capability configuration parameters
		TAddress iAddress;		///< Address to use to set up the call
		};
		
	enum TAlphaIdValidity
		{
		EAlphaIdValidityNotSet,
		EValidAlpaId,
		ENullAlphaId,
		ENoAlphaId
		};
	
	/** 
	* @class TCallControlV1 etelsat.h "inc/etelsat.h"
	* @brief Describes details of the action that 
	* the client has to perform as a result of Call Control by SIM
	*/
	class TCallControlV1 : public TSatBase
		{
	public:
		IMPORT_C TCallControlV1();

		IMPORT_C void SetCcGeneralResult	(TControlResult aResult);
		IMPORT_C void SetCallSetUpDetails	(const TCallSetUpParams& aParams);
		IMPORT_C void SetSendSsDetails		(const TSsString& aString);
		IMPORT_C void SetSendUssdDetails	(const TUssdString& aString);
		IMPORT_C void SetAlphaId			(TAlphaIdValidity aValidity, TAlphaId& aAlphaId); 

		IMPORT_C void GetCallControlType	(TCallControlType& aType) const;
		IMPORT_C void GetCcGeneralResult	(TControlResult& aResult) const;
		IMPORT_C TInt GetCallSetUpDetails	(TCallSetUpParams& aParams) const;
		IMPORT_C TInt GetSendSsDetails		(TSsString& aString) const;
		IMPORT_C TInt GetSendUssdDetails	(TUssdString& aString) const;
		IMPORT_C void GetAlphaId			(TAlphaIdValidity& aValidity,TAlphaId& aAlphaId) const;
	protected:
		TCallControlType iType;				///< Call control type
		TCcp iCcp1;							///< Capability Configuration Parameters 1
		TSubAddress iSubAddress;			///< Remote party sub address
		TCcp iCcp2;							///< Capability Configuration Parameters 2
		TUint8 iDcs;						///< Data Coding Scheme
		TTypeOfNumber iTypeOfNumber;		///< TON
		TNumberingPlan iNumberPlan;			///< NPI
		TBuf<KMaxMobileTelNumberSize> iBuf; ///< Telephone number
		TControlResult iResult;				///< Result of the call control procedure	
		TAlphaIdValidity iValidity;			///< Alpha identifier validity 
		TAlphaId iAlphaId;					///< Alpha identifier		
		};

	typedef TPckg<TCallControlV1>	TCallControlV1Pckg;

	IMPORT_C void NotifyCallControlRequest(TRequestStatus& aReqStatus, TDes8& aCallControlDetails ) const;
	IMPORT_C void NotifyCallControlRequestCancel() const;

	//
	//MO SMS CONTROL
	//

	/** 
	* @class TMoSmControlV1 etelsat.h "inc/etelsat.h"
	* @brief Describes details of the modified (by SIM MO SM Control) SMS.
	*/
	class TMoSmControlV1 : public TSatBase
		{
	public:
		IMPORT_C TMoSmControlV1();
	public:
		TAddress iRpAddress;	///< Rp address
		TAddress iTpAddress;	///< Tp address
		TControlResult iResult; ///< Call control procedure result
		TAlphaId iAlphaId;		///< Alpha Identifier
		};

	typedef TPckg<TMoSmControlV1>	TMoSmControlV1Pckg;

	IMPORT_C void NotifyMoSmControlRequest(TRequestStatus& aReqStatus,TDes8& aMoSmDetails) const;
	IMPORT_C void NotifyMoSmControlRequestCancel() const;

	//
	// EVENT DOWNLOAD
	//
	enum TEventList
		{
		KMTCall				=0x01,
		KCallConnected		=0x02,
		KCallDisconnected	=0x04,
		KLocationStatus		=0x08,
		KUserActivity		=0x10,
		KIdleScreenAvailable=0x20
		};

	/** 
	* @class TEventDownloadV1 etelsat.h "inc/etelsat.h"
	* @brief List of Events that have occured
	*/
	class TEventDownloadV1 : public TSatBase
		{
	public:
		IMPORT_C TEventDownloadV1();
	public:
		TUint iEvent; ///< List of events to be monitored
		};

	typedef TPckg<TEventDownloadV1>  TEventDownloadV1Pckg;

    IMPORT_C void EventDownload(TRequestStatus& aReqStatus, const TDesC8& aEventList) const;	
	IMPORT_C void EventDownloadCancel() const;

	//
	// DISPLAY TEXT
	//
	enum TClearScreenTrigger
		{
		EClearScreenTriggerNotSet,	///< Clear screen trigger not set
		EClearAfterDelay,			///< Clear screen after a specified delay
		EUserClear					///< Clear screen on user action
		};

	enum TDisplayPriority
		{
		EDisplayPriorityNotSet,	///< Display priority not set
		ENormalPriority,		///< Normal display priority
		EHighPriority			///< High display priority
		};

	enum TImmediateRsp 
		{
		EImmediateRspNotSet,
		EImmediateRsp,
		ENoImmediateRsp
		};
	
	enum {KTextToDisplayMaxSize=242};
	typedef TBuf<KTextToDisplayMaxSize> TTextToDisplay;

	/** 
	* @class TDisplayTextV1 etelsat.h "inc/etelsat.h"
	* @brief Display Text proactive command issued by the SIM
	*/
	class TDisplayTextV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TDisplayTextV1();
	public:
		TDisplayPriority iPriority;				///< Text priority
		TClearScreenTrigger iClearScreenTrigger;///< Trigger for screen clearance
		TTextToDisplay iText;					///< Text to display 
		TIconId iIconId;						///< Icon Identifier
		TImmediateRsp iImmediateRsp;			///< Specifies whether immediate response is required.
		};

	typedef TPckg<TDisplayTextV1>  TDisplayTextV1Pckg;

	IMPORT_C void NotifyDisplayTextPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifyDisplayTextPCmdCancel() const;

	/** 
	* @class TDisplayTextRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Display Text proactive command.
	*
	* TDisplayTextRspV1 is packaged into a descriptor,TDisplayTextRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TDisplayTextRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TDisplayTextRspV1();
	public:
		TPCmdResult iGeneralResult;		///< General result of the Pcmd
		TUint iInfoType;				///< Additional information's type
		TAdditionalInfo iAdditionalInfo;///< Additional information 
		};

	typedef TPckg<TDisplayTextRspV1>  TDisplayTextRspV1Pckg;

	//
	//GET INKEY
	//
	enum TGetInkeyRspFormat
		{
		EGetInkeyRspFormatNotSet,
		EDigitOnly,
		ECharSmsDefaultAlphabet,
		ECharUcs2Alphabet,
		EYesNo
		};

	enum {KGetInkeyTextMaxSize=242};
	typedef TBuf<KGetInkeyTextMaxSize> TGetInkeyText;

	/** 
	* @class TGetInkeyV1 etelsat.h "inc/etelsat.h"
	* @brief Get Inkey proactive command issued by the SIM
	*/
	class TGetInkeyV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TGetInkeyV1();
	public:
		TGetInkeyRspFormat iRspFormat;	///< Expected response format
		TGetInkeyText iText;			///< Text to display
		TIconId iIconId;				///< Icon identifier
		THelp iHelp;					///< Help information	
		};

	typedef TPckg<TGetInkeyV1>  TGetInkeyV1Pckg;

	IMPORT_C void NotifyGetInkeyPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifyGetInkeyPCmdCancel() const;

	/** 
	* @class TGetInkeyRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Get Inkey proactive command.
	*
	* TGetInkeyRspV1 is packaged into a descriptor,TGetInkeyRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TGetInkeyRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TGetInkeyRspV1();
	public:
		TPCmdResult iGeneralResult;		///< General result of the Pcmd
		TUint iInfoType;				///< Additional information's type
		TGetInkeyRspFormat iRspFormat;	///< Response Format
		TAdditionalInfo iAdditionalInfo;///< Additional information
		};

	typedef TPckg<TGetInkeyRspV1>  TGetInkeyRspV1Pckg;

	//
	//GET INPUT
	//
	struct TRspLength
		{
		TUint8 iMinRspLength;	///< Minimum length of user input
		TUint8 iMaxRspLength;	///< Maximum lenght of user input
		};

	enum TInputDisplayOption
		{
		EInputDisplayOptionNotSet,
		EDisplayUserInput,
		EHideUserInput
		};

	enum TGetInputRspFormat
		{
		EGetInputRspFormatNotSet,
		EDigitOnlyUnpacked,
		EDigitOnlyPacked,
		ESmsDefaultAlphabetUnpacked,
		ESmsDefaultAlphabetPacked,
		EUcs2Alphabet
		};

	enum {KGetInputTextMaxSize=238};
	typedef TBuf<KGetInputTextMaxSize> TGetInputText;

	enum {KGetInputDefaultTextMaxSize=235};
	typedef TBuf<KGetInputDefaultTextMaxSize> TGetInputDefaultText;

	/** 
	* @class TGetInputV1 etelsat.h "inc/etelsat.h"
	* @brief Get Input proactive command issued by the SIM
	*/
	class TGetInputV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TGetInputV1();
	public:
		TInputDisplayOption iInputDisplayOption;///< Input display option
		TGetInputRspFormat iRspFormat;			///< Response format
		TGetInputText iText;					///< Text to display
		TRspLength iRspLength;					///< Min and max response length
		TGetInputDefaultText iDefaultText;		///< Default text
		TIconId iIconId;						///< Icon identifier
		THelp iHelp;							///< Help info
		};

	typedef TPckg<TGetInputV1>  TGetInputV1Pckg;

	IMPORT_C void NotifyGetInputPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifyGetInputPCmdCancel() const;

	/** 
	* @class TGetInputRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Get Input proactive command.
	*
	* TGetInputRspV1 is packaged into a descriptor,TGetInputRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TGetInputRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TGetInputRspV1();
	public:
		TPCmdResult iGeneralResult;		///< General Pcmd result
		TUint iInfoType;				///< Additional Information's type
		TGetInputRspFormat iRspFormat;	///< Response format
		TAdditionalInfo iAdditionalInfo;///< Additional information
		};

	typedef TPckg<TGetInputRspV1>  TGetInputRspV1Pckg;

	//
	//PLAY TONE
	//

	/// TTone enum values are dictated by ETSI 11.14
	enum TTone
		{
		KToneNotSet							=-1,
		KDialTone							=0x01,
		KCalledSubscriberBusy				=0x02,
		KCongestion							=0x03,
		KRadioPathAcknowledge				=0x04,
		KRadioPathNotAvailableCallDropped	=0x05,
		KErrorSpecialInfo					=0x06,
		KCallWaitingTone					=0x07,
		KRingingTone						=0x08,
		KGeneralBeep						=0x10,
		KPositiveTone						=0x11,
		KNegativeTone						=0x12
		};

	/** 
	* @class TPlayToneV1 etelsat.h "inc/etelsat.h"
	* @brief Play Tone proactive command issued by the SIM
	*/
	class TPlayToneV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TPlayToneV1();
	public:
		TAlphaId iAlphaId;	///< Alpha identifier
		TTone iTone;		///< Tone to play
		TDuration iDuration;///< Tone duration
		};

	typedef TPckg<TPlayToneV1>  TPlayToneV1Pckg;

	IMPORT_C void NotifyPlayTonePCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifyPlayTonePCmdCancel() const;

	/** 
	* @class TPlayToneRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Play Tone proactive command.
	*
	* TPlayToneRspV1 is packaged into a descriptor,TPlayToneRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TPlayToneRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TPlayToneRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional information type
		TAdditionalInfo iAdditionalInfo;///< Additional information 
		};

	typedef TPckg<TPlayToneRspV1>  TPlayToneRspV1Pckg;

	//
	//Menu Items Base Class
	//
	enum TMenuContent
		{
		KItems				= 0x01,	
		KItemNextActions	= 0x02,
		KItemIconIds		= 0x04	
		};

	enum {KMenuItemMaxSize=240};

	struct TItem
		{
		TUint8 iItemId;							///< SAT menu item indentifier
		TBuf16<KMenuItemMaxSize> iItemString;	///< SAT menu item string
		};

	enum {KItemListMaxSize=486}; 
	typedef TBuf16<KItemListMaxSize> TItemList;

	/** 
	* @class TMenuItemBaseV1 etelsat.h "inc/etelsat.h"
	* @brief Base class for menu item based classes.
	*
	* TMenuItemBase is the base class for TSetUpMenuV1 and TSelectItemV1.
	* Provides methods to add and get the menu items, as well as retrieve the menu 
	* content and the number of items.
	*/
	class TMenuItemBaseV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TMenuItemBaseV1();
		IMPORT_C TBool IsRemoveMenu() const;

		IMPORT_C TInt MenuContent() const;
		IMPORT_C TUint NumberOfItems() const;

		IMPORT_C TInt GetItem    (TUint aIndex, TItem& aItem) const;
		IMPORT_C TInt GetItem    (TUint aIndex, TItem& aItem, TInt& aAction) const;
		IMPORT_C TInt GetItemIcon(TUint aIndex, TItem& aItem, TInt& aIconId) const;
		IMPORT_C TInt GetItem    (TUint aIndex, TItem& aItem, TInt& aAction, TInt& aIconId) const;

		IMPORT_C TInt AddItem    (const TItem& aItem);
		IMPORT_C TInt AddItem    (const TItem& aItem, TUint aAction);
		IMPORT_C TInt AddItemIcon(const TItem& aItem, TUint aIconId);
		IMPORT_C TInt AddItem    (const TItem& aItem, TUint aAction, TUint aIconId);

		IMPORT_C void Reset();

	protected:
		///TMenuItemHeader enum values are chosen arbitrary
		enum TMenuItemHeader
			{
			KItemHeader		=0xAA00,
			KActionHeader	=0xBB00,
			KIconIdHeader	=0xCC00
			};

		enum TBitMask
			{
			KLowerByte	=0x00FF,
			KUpperByte	=0xFF00
			};

		// Length = 1 word = 2 bytes
		enum {KHeaderLength=0x01};
		enum {KItemIdLength=0x01};
		enum {KActionLength=0x01};
		enum {KIconIdLength=0x01};

		TInt FindItemInBuffer(TUint aIndex, TInt& aOffset) const;
		TUint iNumberOfItems;	///< Number of items in the menu
		TUint8 iMenuContent;	///< Content of the menu: items + next actions + icon ids
		TItemList iBuf;			///< List of the items in the menu
		};

	//
	//SET UP MENU
	//
	/** 
	* @class TSetUpMenuV1 etelsat.h "inc/etelsat.h"
	* @brief Set Up Menu proactive command issued by the SIM.
	*
	* TSetUpMenuV1 derives from TMenuItemBaseV1, which provides the basic
	* mechanism to handle the menu items, item next actions and item icon ids.
	*/
	class TSetUpMenuV1 : public TMenuItemBaseV1
		{
	public:
		IMPORT_C TSetUpMenuV1();
	public:
		TAlphaId iAlphaId;					///< Alpha identifier
		THelp iHelp;						///< Help information
		TIconId iIconId;					///< Icon identifier
		TIconQualifier iIconListQualifier;	///< Icon list qualifier
		};

	typedef TPckg<TSetUpMenuV1>  TSetUpMenuV1Pckg;

	IMPORT_C void NotifySetUpMenuPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySetUpMenuPCmdCancel() const;

	/** 
	* @class TSetUpMenuRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Set Up Menu proactive command.
	*
	* TSetUpMenuRspV1 is packaged into a descriptor,TSetUpMenuRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSetUpMenuRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpMenuRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional information type
		TAdditionalInfo iAdditionalInfo;///< Additional information 
		};

	typedef TPckg<TSetUpMenuRspV1>  TSetUpMenuRspV1Pckg;


	//
	//SELECT ITEM
	//
	enum TPresentationType
		{
		EPresentationTypeNotSet,
		ENotSpecified,
		EDataValues,
		ENavigationOptions
		};

	/** 
	* @class TSelectItemV1 etelsat.h "inc/etelsat.h"
	* @brief Select Item proactive command issued by the SIM.
	*
	* TSelectItemV1 derives from TMenuItemBaseV1, which provides the basic
	* mechanism to handle the menu items, item next actions and item icon ids.
	*/
	class TSelectItemV1 : public TMenuItemBaseV1
		{
	public:
		IMPORT_C TSelectItemV1();
	public:
		TPresentationType iPresentationType;///< Presentation type
		TAlphaId iAlphaId;					///< Alpha identifier
		THelp iHelp;						///< Help information
		TUint8 iDefaultItemId;				///< Default item id
		TIconId iIconId;					///< Icon identifier
		TIconQualifier iIconListQualifier;	///< Icon list qualifier
		};


	typedef TPckg<TSelectItemV1>  TSelectItemV1Pckg;

	IMPORT_C void NotifySelectItemPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySelectItemPCmdCancel() const;

	/** 
	* @class TSelectItemRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Select Item proactive command.
	*
	* TSelectItemRspV1 is packaged into a descriptor,TSelectItemRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSelectItemRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSelectItemRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional information type
		TAdditionalInfo iAdditionalInfo;///< Additional information 
		};

	typedef TPckg<TSelectItemRspV1>  TSelectItemRspV1Pckg;


	//
	// SEND SHORT MESSAGE
	//
	enum {KTpduMaxSize=248};
	typedef TBuf8<KTpduMaxSize> TTpdu;

	/** 
	* @class TSendSmV1 etelsat.h "inc/etelsat.h"
	* @brief Send Sm proactive command issued by the SIM.
	*/
	class TSendSmV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendSmV1();
	public:
		TAlphaId iAlphaId;	///< Alpha identifier
		TAddress iAddress;	///< Remote party addess
		TTpdu iSmsTpdu;		///< Sms TPDU
		TIconId iIconId;	///< Icon identifier
		};

	typedef TPckg<TSendSmV1>  TSendSmV1Pckg;

	IMPORT_C void NotifySendSmPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySendSmPCmdCancel() const;

	/** 
	* @class TSendSmRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Send Sm proactive command.
	*
	* TSendSmRspV1 is packaged into a descriptor,TSendSmRspV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSendSmRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendSmRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional Info type
		TAdditionalInfo iAdditionalInfo;///< Additional information
		};

	typedef TPckg<TSendSmRspV1>  TSendSmRspV1Pckg;

	//
	// Send SM no logging permitted
	//
	class TSatSmsV1: public TSatBase
		{
	public:
		IMPORT_C TSatSmsV1();
	public:
		TTpdu iBuf;				///< SMS TPDU
		TAddress iServiceCenter;///< If iServiceCenter is a null buffer then use the default sc address
		};

	typedef TPckg<TSatSmsV1> TSatSmsV1Pckg;
	
	IMPORT_C void SendMessageNoLogging(TRequestStatus& aReqStatus, const TDesC8& aMsg, TUint16& aMsgRef) const;
	IMPORT_C void SendMessageNoLoggingCancel() const;


	//
	//SEND SS
	//
	/** 
	* @class TSendSsV1 etelsat.h "inc/etelsat.h"
	* @brief Send SS proactive command issued by the SIM.
	*/
	class TSendSsV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendSsV1();
	public:
		TAlphaId iAlphaId;	///< Alpha identifier
		TSsString iSsString;///< SS string
		TIconId iIconId;	///< Icon identifier
		};

	typedef TPckg<TSendSsV1>  TSendSsV1Pckg;

	IMPORT_C void NotifySendSsPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySendSsPCmdCancel() const;

	/** 
	* @class TSendSsRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Send SS proactive command.
	*
	* TSendSsRspV1 is packaged into a descriptor,TSendSsV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSendSsRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendSsRspV1();
	public:
		TPCmdResult iGeneralResult;			///< PCmd general result
		TUint iInfoType;					///< Additional info type
		TAdditionalInfo iAdditionalInfo;	///< Additional info
		TPCmdResult iGeneralResult2;		///< Second PCmd general result
		TUint iInfoType2;					///< Second additional info type
		TAdditionalInfo iAdditionalInfo2;	///< Second additional info
		TCallControlV1 iCcRequestedAction;	///< Action requested by the call control procedure
		};

	typedef TPckg<TSendSsRspV1>  TSendSsRspV1Pckg;

	//
	//SEND USSD
	//
	/** 
	* @class TSendUssdV1 etelsat.h "inc/etelsat.h"
	* @brief Send USSD proactive command issued by the SIM.
	*/
	class TSendUssdV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendUssdV1();
	public:
		TAlphaId iAlphaId;		///< Alpha identifier
		TUssdString iUssdString;///< USSD string
		TIconId iIconId;		///< Icon identifier
		};

	typedef TPckg<TSendUssdV1>  TSendUssdV1Pckg;

	IMPORT_C void NotifySendUssdPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySendUssdPCmdCancel() const;

	/** 
	* @class TSendUssdRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Send USSD proactive command.
	*
	* TSendUssdRspV1 is packaged into a descriptor,TSendUssdV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSendUssdRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendUssdRspV1();
	public:
		TPCmdResult iGeneralResult;			///< PCmd general result
		TUint iInfoType;					///< Additional info type
		TAdditionalInfo iAdditionalInfo;	///< Additional info
		TPCmdResult iGeneralResult2;		///< Pcmd second general result
		TUint iInfoType2;					///< Second additional info type
		TAdditionalInfo iAdditionalInfo2;	///< Second additional info
		TUssdString iUssdString;			///< USSD string	
		TCallControlV1 iCcRequestedAction;	///< Action requested by the call control procedure.
		};

	typedef TPckg<TSendUssdRspV1>  TSendUssdRspV1Pckg;

	
	//
	//SET UP CALL
	//
	enum TSetUpCallType
		{
		ESetUpCallTypeNotSet,
		EOnlyIfNotBusy,
		EOnlyIfNotBusyWithRedial,
		EHoldOtherCalls,
		EHoldOtherCallsWithRedial,
		EDisconnectOtherCalls,
		EDisconnectOtherCallsWithRedial
		};

	/** 
	* @class TSetUpCallV1 etelsat.h "inc/etelsat.h"
	* @brief Set Up Call proactive command issued by the SIM.
	*/
	class TSetUpCallV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpCallV1();
	public:
		TSetUpCallType iType;				///< Conditions surrounding the set up call
		TAlphaId iAlphaIdConfirmationPhase; ///< Alpha identifier to use during the confirmation phase
		TIconId iIconIdConfirmationPhase;	///< Icon identifier to use during the confirmation phase
		TAddress iAddress;					///< Address to set up the call with
		TCcp iCapabilityConfigParams;		///< Capability configuration parameters
		TSubAddress iSubAddress;			///< Remote party subaddress
		TDuration iDuration;				///< Maximum duration of redials
		TAlphaId iAlphaIdCallSetUpPhase;	///< Alpha identifier to use during the call set up phase
		TIconId iIconIdCallSetUpPhase;		///< Icon identifier to use during the call set up phase
		};

	typedef TPckg<TSetUpCallV1>  TSetUpCallV1Pckg;

	IMPORT_C void NotifySetUpCallPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySetUpCallPCmdCancel() const;

	/** 
	* @class TSetUpCallRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Set Up Call proactive command.
	*
	* TSetUpCallRspV1 is packaged into a descriptor,TSetUpCallV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSetUpCallRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpCallRspV1();
	public:
		TPCmdResult iGeneralResult;			///< PCmd general result
		TUint iInfoType;					///< Additional information type
		TAdditionalInfo iAdditionalInfo;	///< Additional info
		TPCmdResult iGeneralResult2;		///< PCmd second result
		TUint iInfoType2;					///< Second additional info type
		TAdditionalInfo iAdditionalInfo2;	///< Second additional info
		TCallControlV1 iCcRequestedAction;	///< Action requested by the call control procedure
		};

	typedef TPckg<TSetUpCallRspV1>  TSetUpCallRspV1Pckg;

	//
	//REFRESH
	//

	/// The enum values of TElementaryFiles are derived directly from ETSI 11.14
	enum TElementaryFiles
		{
		KElpEf				=0x2F05,	///< Extended Language Preference EF
		KImgEf				=0x4F20,	///< Image EF
		KLpEf				=0x6F05,	///< Language Preference EF
		KImsiEf				=0x6F07,	///< IMSI EF
		KDckEf				=0x6F2C,	///< De-personalization Control Keys EF
		KPlmnSelEf			=0x6F30,	///< PLMN Selection EF
		KHplmnEf			=0x6F31,	///< Home PLMN EF
		KCnlEf				=0x6F32,	///< Co-operative Network List EF
		KAcmMaxEf			=0x6F37,	///< ACM max value EF
		KSstEf				=0x6F38,	///< SIM Service Table EF
		KAcmEf				=0x6F39,	///< Accumulated Call Meter EF
		KAdnEf				=0x6F3A,	///< Abbreviated Dialling Numbers EF
		KFdnEf				=0x6F3B,	///< Fixed Diallind Numbers EF
		KSmsEf				=0x6F3C,	///< Short Messages EF
		KCcpEf				=0x6F3D,	///< Capability Configuration Parameters EF
		KGid1Ef				=0x6F3E,	///< Group Identifier Level 1 EF
		KGid2Ef				=0x6F3F,	///< Group Identifier Level 2 EF
		KMsisdnEf			=0x6F40,	///< MS ISDN EF
		KPuctEf				=0x6F41,	///< Price per Unit and Currency Table EF
		KSmspEf				=0x6F42,	///< SMS Parameters EF
		KSmssEf				=0x6F43,	///< SMS Status EF
		KLndEf				=0x6F44,	///< Last Number Dialled EF
		KCbmiEf				=0x6F45,	///< Cell Broadcast Message Identifier
		KSpnEf				=0x6F46,	///< Service Provider Name EF
		KSmsrEf				=0x6F47,	///< SMS reports EF
		KCbmidEf			=0x6F48,	///< CBMI for Data Download EF
		KSdnEf				=0x6F49,	///< Service Dialling Numbers EF 
		KExt1Ef				=0x6F4A,	///< Extension 1 EF
		KExt2Ef				=0x6F4B,	///< Extension 2 EF
		KExt3Ef				=0x6F4C,	///< Extension 3 EF
		KBdnEf				=0x6F4D,	///< Barred Dialling Numbers EF
		KExt4Ef				=0x6F4E,	///< Extension 4 EF
		KCbmirEf			=0x6F50,	///< CBMI Range Selection EF
		KNiaEf				=0x6F51,	///< Network's Indication of Alerting EF
		KLociGprsEf			=0x6F53,	///< GPRS Location Information EF
		KSumeEf				=0x6F54,	///< SetUpMenu Elements EF
		KAccEf				=0x6F78,	///< Access Control Class EF
		KFPlmnEf			=0x6F7B,	///< Forbidden PLMN EF
		KAdEf				=0x6FAD,	///< Administrative Data EF
		KPhaseEf			=0x6FAE,	///< Phase Identification EF
		KVcgsEf				=0x6FB1,	///< Voice Group Call Service EF
		KVgcssEf			=0x6FB2,	///< Voice Group Call Service Status EF
		KVbsEf				=0x6FB3,	///< Voice Broadcast Service EF
		KVbssEf				=0x6FB4,	///< Voice Broadcast Service Status EF
		KeMlppEf			=0x6FB5,	///< enhanced Multi Level Pre-emption and Priority EF
		KAaemef				=0x6FB6,	///< Automatic Answer for eMLLP Service EF
		KEccEf				=0x6FB7		///< Emergency Call Codes EF
		};

	enum TRefreshType
		{
		ERefreshTypeNotSet,
		ESimInitFullFileChangeNotification,
		EFileChangeNotification,
		ESimInitFileChangeNotification,
		ESimInit,
		ESimReset
		};

	enum {KRefreshedFileListMaxSize=242};
	typedef TBuf16<KRefreshedFileListMaxSize> TRefreshFileList;

	/** 
	* @class TRefreshV1 etelsat.h "inc/etelsat.h"
	* @brief Refresh proactive command issued by the SIM.
	*/
	class TRefreshV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TRefreshV1();
	public:
		TRefreshType iType;			///< Type of refresh command
		TRefreshFileList iFileList;	///< Optional list of files that need to be refreshed.
		};

	typedef TPckg<TRefreshV1>  TRefreshV1Pckg;

	IMPORT_C void NotifyRefreshPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifyRefreshPCmdCancel() const;

	/** 
	* @class TRefreshRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Refresh proactive command.
	*
	* TRefreshRspV1 is packaged into a descriptor,TRefreshV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TRefreshRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TRefreshRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional info type
		TAdditionalInfo iAdditionalInfo;///< Additional info 
		};

	typedef TPckg<TRefreshRspV1>  TRefreshRspV1Pckg;

	//
	//SET UP EVENT LIST
	//
	enum TSetUpEventListType
		{
		ESetUpEventListTypeNotSet,
		EUpdateEventList,
		ERemoveExistingEventList
		};

	/** 
	* @class TSetUpEventListV1 etelsat.h "inc/etelsat.h"
	* @brief Set Up Event List proactive command issued by the SIM.
	*/
	class TSetUpEventListV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpEventListV1();
	public:
		TSetUpEventListType iType;	///< Update or remove the existing event list
		TUint iEvents;				///< Sum of the relevant TEventList caps values.
		};

	typedef TPckg<TSetUpEventListV1>  TSetUpEventListV1Pckg;

	IMPORT_C void NotifySetUpEventListPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySetUpEventListPCmdCancel() const;

	/** 
	* @class TSetUpEventListRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Set Up Event List proactive command.
	*
	* TSetUpEventListRspV1 is packaged into a descriptor,TSetUpEventListV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSetUpEventListRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpEventListRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional info type
		TAdditionalInfo iAdditionalInfo;///< Additional info 
		};

	typedef TPckg<TSetUpEventListRspV1>  TSetUpEventListRspV1Pckg;

	//
	//SET UP IDLE MODE TEXT
	//
	enum TSetUpIdleModeTextType
		{
		ESetUpIdleModeTextTypeNotSet,
		EUpdateIdleModeText,
		ERemoveExistingIdleModeText
		};

	enum {KIdleModeTextMaxSize=242};
	typedef TBuf<KIdleModeTextMaxSize> TIdleModeText;

	/** 
	* @class TSetUpIdleModeTextV1 etelsat.h "inc/etelsat.h"
	* @brief Set Up Idle Mode Text proactive command issued by the SIM.
	*/
	class TSetUpIdleModeTextV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpIdleModeTextV1();
	public:
		TSetUpIdleModeTextType iType;	///< Update or remove the existing idle mode text
		TIdleModeText iText;			///< New idle mode text
		TIconId iIconId;				///< Icon identifier
		};

	typedef TPckg<TSetUpIdleModeTextV1>  TSetUpIdleModeTextV1Pckg;

	IMPORT_C void NotifySetUpIdleModeTextPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySetUpIdleModeTextPCmdCancel() const;

	/** 
	* @class TSetUpIdleModeTextRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Set Up Idle Mode Text proactive command.
	*
	* TSetUpIdleModeTextRspV1 is packaged into a descriptor,TSetUpIdleModeTextV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSetUpIdleModeTextRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSetUpIdleModeTextRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional info type
		TAdditionalInfo iAdditionalInfo;///< Additional info 
		};

	typedef TPckg<TSetUpIdleModeTextRspV1>  TSetUpIdleModeTextRspV1Pckg;


	//
	//SEND DTMF COMMAND
	//
	enum{KDtmfStringMaxSize=243}; 
	typedef	TBuf<KDtmfStringMaxSize> TDtmfString;

	/** 
	* @class TSendDtmfV1 etelsat.h "inc/etelsat.h"
	* @brief Send Dtmf proactive command issued by the SIM.
	*/
	class TSendDtmfV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendDtmfV1();
	public:
		TAlphaId iAlphaId;		///< Alpha Identifier
		TDtmfString iDtmfString;///< DTMF string
		TIconId iIconId;		///< Icon identifer
		};

	typedef TPckg<TSendDtmfV1>  TSendDtmfV1Pckg;

	IMPORT_C void NotifySendDtmfPCmd(TRequestStatus& aReqStatus, TDes8& aPCmd) const;
	IMPORT_C void NotifySendDtmfPCmdCancel() const;

	/** 
	* @class TSendDtmfRspV1 etelsat.h "inc/etelsat.h"
	* @brief Client response to a Send DTMF proactive command.
	*
	* TSendDtmfRspV1 is packaged into a descriptor,TSendDtmfV1Pckg,
	* and passed back to the TSY within RSat::TerminalRsp.
	*/
	class TSendDtmfRspV1 : public TSatPCmdBase
		{
	public:
		IMPORT_C TSendDtmfRspV1();
	public:
		TPCmdResult iGeneralResult;		///< PCmd general result
		TUint iInfoType;				///< Additional info type
		TAdditionalInfo iAdditionalInfo;///< Additional info 
		};

	typedef TPckg<TSendDtmfRspV1>  TSendDtmfRspV1Pckg;

protected:
	IMPORT_C virtual void ConstructL();
	IMPORT_C virtual void Destruct();

private:
	
	RSat(const RSat& aSat); ///< Default copy constructor
	CSatPtrHolder* iEtelSatPtrHolder;

	};

#endif

